@@ -6,7 +6,7 @@
  * most of the methods can be used separately as well.
  *
  * Copyright 2009 Benedikt Hallinger
- * Copyright 2010-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2015 Horde LLC (http://www.horde.org/)
  *
  * @category  Horde
  * @package   Ldap
@@ -76,15 +76,14 @@ class Horde_Ldap_Util
      */
     public static function explodeDN($dn, array $options = array())
     {
-        if (!isset($options['onlyvalues'])) {
-            $options['onlyvalues'] = false;
-        }
-        if (!isset($options['reverse'])) {
-            $options['reverse'] = false;
-        }
-        if (!isset($options['casefold'])) {
-            $options['casefold'] = 'upper';
-        }
+        $options = array_merge(
+            array(
+                'casefold' => 'upper',
+                'onlyvalues' => false,
+                'reverse' => false,
+            ),
+            $options
+        );
 
         // Escaping of DN and stripping of "OID.".
         $dn = self::canonicalDN($dn, array('casefold' => $options['casefold']));
@@ -284,7 +283,7 @@ class Horde_Ldap_Util
      *
      * @return boolean|string The canonical DN or false if the DN is not valid.
      */
-    public static function canonicalDN($dn, $options = array())
+    public static function canonicalDN($dn, array $options = array())
     {
         if ($dn === '') {
             // Empty DN is valid.
@@ -292,19 +291,20 @@ class Horde_Ldap_Util
         }
 
         // Options check.
-        $options['reverse'] = !empty($options['reverse']);
-        if (!isset($options['casefold'])) {
-            $options['casefold'] = 'upper';
-        }
-        if (!isset($options['separator'])) {
-            $options['separator'] = ',';
-        }
+        $options = array_merge(
+            array(
+                'casefold' => 'upper',
+                'reverse' => false,
+                'separator' => ',',
+            ),
+            $options
+        );
 
         if (!is_array($dn)) {
             // It is not clear to me if the perl implementation splits by the
             // user defined separator or if it just uses this separator to
             // construct the new DN.
-            $dn = preg_split('/(?<!\\\\)' . $options['separator'] . '/', $dn);
+            $dn = preg_split('/(?<!\\\\)' . preg_quote($options['separator']) . '/', $dn);
 
             // Clear wrong splitting (possibly we have split too much).
             $dn = self::_correctDNSplitting($dn, $options['separator']);
@@ -347,7 +347,7 @@ class Horde_Ldap_Util
                     if (!is_int($subkey)) {
                         $subval = $subkey . '=' . $subval;
                     }
-                    $subval_processed = self::canonicalDN($subval);
+                    $subval_processed = self::canonicalDN($subval, $options);
                     if (false === $subval_processed) {
                         return false;
                     }
@@ -366,7 +366,7 @@ class Horde_Ldap_Util
                     // Sort RDN keys alphabetically.
                     sort($rdns, SORT_STRING);
                     foreach ($rdns as $rdn) {
-                        $subval_processed = self::canonicalDN($rdn);
+                        $subval_processed = self::canonicalDN($rdn, $options);
                         if (false === $subval_processed) {
                             return false;
                         }
