@@ -3,7 +3,7 @@
 require_once __DIR__ . '/TestBase.php';
 
 /**
- * Copyright 2010-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2015 Horde LLC (http://www.horde.org/)
  *
  * @package    Ldap
  * @subpackage UnitTests
@@ -18,21 +18,26 @@ class Horde_Ldap_LdapTest extends Horde_Ldap_TestBase
             return;
         }
 
-        $ldap = new Horde_Ldap(self::$ldapcfg['server']);
         $clean = array('cn=Horde_Ldap_TestEntry,',
                        'ou=Horde_Ldap_Test_subdelete,',
                        'ou=Horde_Ldap_Test_modify,',
                        'ou=Horde_Ldap_Test_search1,',
                        'ou=Horde_Ldap_Test_search2,',
                        'ou=Horde_Ldap_Test_exists,',
+                       'ou=Horde_Ldap_Test_exists_2+l=somewhere,',
                        'ou=Horde_Ldap_Test_getEntry,',
                        'ou=Horde_Ldap_Test_move,',
                        'ou=Horde_Ldap_Test_pool,',
                        'ou=Horde_Ldap_Test_tgt,');
-        foreach ($clean as $dn) {
-            try {
-                $ldap->delete($dn . self::$ldapcfg['server']['basedn'], true);
-            } catch (Exception $e) {}
+        try {
+            $ldap = new Horde_Ldap(self::$ldapcfg['server']);
+            foreach ($clean as $dn) {
+                try {
+                    $ldap->delete($dn . self::$ldapcfg['server']['basedn'], true);
+                } catch (Exception $e) {
+                }
+            }
+        } catch (Exception $e) {
         }
     }
 
@@ -42,15 +47,23 @@ class Horde_Ldap_LdapTest extends Horde_Ldap_TestBase
     public function testConnectAndPrivilegedBind()
     {
         // This connect is supposed to fail.
-        $lcfg = array('hostspec' => 'nonexistant.ldap.horde.org');
+        $lcfg = array(
+            'hostspec' => 'nonexistant.ldap.horde.org',
+            'timeout' => 1,
+        );
         try {
             $ldap = new Horde_Ldap($lcfg);
             $this->fail('Horde_Ldap_Exception expected.');
         } catch (Horde_Ldap_Exception $e) {}
 
         // Failing with multiple hosts.
-        $lcfg = array('hostspec' => array('nonexistant1.ldap.horde.org',
-                                          'nonexistant2.ldap.horde.org'));
+        $lcfg = array(
+            'hostspec' => array(
+                'nonexistant1.ldap.horde.org',
+                'nonexistant2.ldap.horde.org'
+            ),
+            'timeout' => 1,
+        );
         try {
             $ldap = new Horde_Ldap($lcfg);
             $this->fail('Horde_Ldap_Exception expected.');
@@ -60,11 +73,16 @@ class Horde_Ldap_LdapTest extends Horde_Ldap_TestBase
         $ldap = new Horde_Ldap(self::$ldapcfg['server']);
 
         // Working connect and privileged bind with first host down.
-        $lcfg = array('hostspec' => array('nonexistant.ldap.horde.org',
-                                          self::$ldapcfg['server']['hostspec']),
-                      'port'      => self::$ldapcfg['server']['port'],
-                      'binddn'    => self::$ldapcfg['server']['binddn'],
-                      'bindpw'    => self::$ldapcfg['server']['bindpw']);
+        $lcfg = array(
+            'hostspec' => array(
+                'nonexistant.ldap.horde.org',
+                self::$ldapcfg['server']['hostspec']
+            ),
+            'port'    => self::$ldapcfg['server']['port'],
+            'binddn'  => self::$ldapcfg['server']['binddn'],
+            'bindpw'  => self::$ldapcfg['server']['bindpw'],
+            'timeout' => 1,
+        );
         $ldap = new Horde_Ldap($lcfg);
     }
 
@@ -309,7 +327,7 @@ class Horde_Ldap_LdapTest extends Horde_Ldap_TestBase
         $ou1_1 = Horde_Ldap_Entry::createFresh(
             'ou=Horde_Ldap_Test_search1_1,' . $ou1->dn(),
             array('objectClass' => array('top','organizationalUnit'),
-                  'ou' => 'Horde_Ldap_Test_search2'));
+                  'ou' => 'Horde_Ldap_Test_search1_1'));
         $ou2 = Horde_Ldap_Entry::createFresh(
             'ou=Horde_Ldap_Test_search2,' . $base,
             array('objectClass' => array('top','organizationalUnit'),
@@ -403,12 +421,14 @@ class Horde_Ldap_LdapTest extends Horde_Ldap_TestBase
         // Testing not existing DN.
         $this->assertFalse($ldap->exists($dn));
 
-        // Passing an entry object (should work). It should return false,
+        // Passing an entry object (should work). exists() should return false,
         // because we didn't add the test entry yet.
         $ou1 = Horde_Ldap_Entry::createFresh(
             $dn,
-            array('objectClass' => array('top', 'organizationalUnit'),
-                  'ou' => 'Horde_Ldap_Test_search1'));
+            array('objectClass' => array('top', 'organizationalUnit'))
+        );
+
+        $this->assertFalse($ldap->exists($dn));
         $this->assertFalse($ldap->exists($ou1));
 
         // Testing not existing DN.
@@ -420,6 +440,16 @@ class Horde_Ldap_LdapTest extends Horde_Ldap_TestBase
             $ldap->exists(1.234);
             $this->fail('Horde_Ldap_Exception expected.');
         } catch (Horde_Ldap_Exception $e) {}
+
+        // Testing multivalued RDNs.
+        $dn = 'ou=Horde_Ldap_Test_exists_2+l=somewhere,' . self::$ldapcfg['server']['basedn'];
+        $ou2 = Horde_Ldap_Entry::createFresh(
+            $dn,
+            array('objectClass' => array('top', 'organizationalUnit'))
+        );
+        $this->assertFalse($ldap->exists($dn));
+        $ldap->add($ou2);
+        $this->assertTrue($ldap->exists($dn));
     }
 
     /**
