@@ -3,7 +3,7 @@
 require_once __DIR__ . '/TestBase.php';
 
 /**
- * Copyright 2010-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2015 Horde LLC (http://www.horde.org/)
  *
  * @package    Ldap
  * @subpackage UnitTests
@@ -17,9 +17,18 @@ class Horde_Ldap_SearchTest extends Horde_Ldap_TestBase
         if (!self::$ldapcfg) {
             return;
         }
-        $ldap = new Horde_Ldap(self::$ldapcfg['server']);
-        $ldap->delete('ou=Horde_Ldap_Test_search1,' . self::$ldapcfg['server']['basedn']);
-        $ldap->delete('ou=Horde_Ldap_Test_search2,' . self::$ldapcfg['server']['basedn']);
+        try {
+            $ldap = new Horde_Ldap(self::$ldapcfg['server']);
+            try {
+                $ldap->delete('ou=Horde_Ldap_Test_search1,' . self::$ldapcfg['server']['basedn']);
+            } catch (Exception $e) {
+            }
+            try {
+                $ldap->delete('ou=Horde_Ldap_Test_search2,' . self::$ldapcfg['server']['basedn']);
+            } catch (Exception $e) {
+            }
+        } catch (Exception $e) {
+        }
     }
 
     /**
