@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2010-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2015 Horde LLC (http://www.horde.org/)
  *
  * @package    Ldap
  * @subpackage UnitTests
@@ -223,9 +223,9 @@ class Horde_Ldap_UtilTest extends Horde_Test_Case
      */
     public function testExplodeDN()
     {
-        $dn = 'OU=Sales+CN=J. Smith,dc=example,dc=net';
+        $dn = 'ou=Sales+CN=J. Smith,dc=example,dc=net';
         $expected_casefold_none = array(
-            array('CN=J. Smith', 'OU=Sales'),
+            array('CN=J. Smith', 'ou=Sales'),
             'dc=example',
             'dc=net'
         );
